amdgpu: remove bo_handle from amdgpu_cs_ib_info, IBs should be in buffer list

Reviewed-by: Christian König <christian.koenig@amd.com>
diff --git a/amdgpu/amdgpu.h b/amdgpu/amdgpu.h
index 451437d..70b488e 100644
--- a/amdgpu/amdgpu.h
+++ b/amdgpu/amdgpu.h
@@ -283,8 +283,8 @@
 	/** Special flags */
 	uint64_t      flags;
 
-	/** Handle of command buffer */
-	amdgpu_bo_handle bo_handle;
+	/** Virtual MC address of the command buffer */
+	uint64_t      ib_mc_address;
 
 	/**
 	 * Size of Command Buffer to be submitted.
@@ -293,9 +293,6 @@
 	 *   - Could be 0
 	 */
 	uint32_t       size;
-
-	/** Offset in the IB buffer object (in unit of dwords) */
-	uint32_t	offset_dw;
 };
 
 /**